@@ -1,9 +1,9 @@
 import os
 import logging
-from types import SimpleNamespace
 from laboro.error import LaboroError
 from laboro.history import History
 from laboro.workspace import Workspace
+from laboro.context.store import Store
 from laboro.config.manager import Manager as ConfigMgr
 from laboro.module.manager import Manager as ModuleMgr
 from laboro.error.handler import Handler as ErrorHandler
@@ -12,8 +12,7 @@ from laboro.error.handler import Handler as ErrorHandler
 class Context:
   def __init__(self, logger):
     self.logger = logger
-    self.store = SimpleNamespace(memory=dict(),
-                                 files=dict())
+    self.store = Store()
     self.history = None
     self.modulemgr = ModuleMgr()
     self.configmgr = ConfigMgr("/etc/laboro/laboro.yml")
@@ -72,25 +71,43 @@ class Context:
   def install_packages(self):
     """Install all packages listed in the workflow configuration file.
     """
-    packages = self.configmgr.get_parameter("workflow",
-                                            "$.laboro.workflow.packages")
+    packages = self.configmgr.get_parameter("workflow", "$.packages")
     for pkg in packages:
       self.modulemgr.install_package(pkg)
 
-  def register_class(self, module, cls):
+  def put(self, prop, value):
+    self.store.put(prop, value)
+
+  def get(self, prop):
+    return self.store.get(prop)
+
+  def _register_class(self, module, cls):
     self.modulemgr.register_class_from_module(cls, module)
 
-  def register_instance_secrets(self, instance, args):
-    class_args = instance.specification["args"]
-    secret_keys = [arg["name"] for arg in class_args if arg["secret"]]
-    secrets = [args[key] for key in args.keys() if key in secret_keys]
-    list(map(logging.getLogger().vault.add, secrets))
-
-  def register_method_secrets(self, instance, action, args):
-    try:
-      method_args = [meth for meth in instance.specification["methods"] if meth["name"] == action][0]["args"]
-      secret_keys = [arg["name"] for arg in method_args if arg["secret"]]
+  def _register_instance_secrets(self, instance, args):
+    if args is not None:
+      class_args = instance.specification["args"]
+      secret_keys = [arg["name"] for arg in class_args if arg["secret"]]
       secrets = [args[key] for key in args.keys() if key in secret_keys]
       list(map(logging.getLogger().vault.add, secrets))
-    except IndexError as err:
-      raise LaboroError(f"UnknownMethodError: Unknown method {instance.__class__.__name__}.{action}") from err
+
+  def _instantiate(self, module, cls, args):
+    logging.info(f"[+] Object instantiation: {module}.{cls}")
+    mod = self.modulemgr.get_class_from_module(cls=cls, module=module)
+    instance = mod(context=self, args=args)
+    self._register_instance_secrets(instance, args)
+    return mod(context=self, args=args)
+
+  def instantiate(self, module, cls, args):
+    self._register_class(module, cls)
+    return self._instantiate(module, cls, args)
+
+  def register_method_secrets(self, instance, method, args):
+    if args is not None:
+      try:
+        method_args = [meth for meth in instance.specification["methods"] if meth["name"] == method][0]["args"]
+        secret_keys = [arg["name"] for arg in method_args if arg["secret"]]
+        secrets = [args[key] for key in args.keys() if key in secret_keys]
+        list(map(logging.getLogger().vault.add, secrets))
+      except IndexError as err:
+        raise LaboroError(f"UnknownMethodError: Unknown method {instance.__class__.__name__}.{method}") from err
